# Pandascore Python SDK 1.0.0

Welcome to the Pandascore SDK documentation. This guide will help you get started with integrating and using the Pandascore SDK in your project.

## Versions

- API version: `2.53.0`
- SDK version: `1.0.0`

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [Access Token Authentication](#access-token-authentication)
- [Using Union Types](#using-union-types)
- [Services](#services)
- [Models](#models)
- [License](#license)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install pandascore-client
```

## Authentication

### Access Token Authentication

The Pandascore API uses an Access Token for authentication.

This token must be provided to authenticate your requests to the API.

#### Setting the Access Token

When you initialize the SDK, you can set the access token as follows:

```py
Pandascore(
    access_token="YOUR_ACCESS_TOKEN"
)
```

If you need to set or update the access token after initializing the SDK, you can use:

```py
sdk.set_access_token("YOUR_ACCESS_TOKEN")
```

## Using Union Types

Union types allow you to specify that a variable can have more than one type. This is particularly useful when a function can accept multiple types of inputs. The Union type hint is used for this purpose.

### Example Function with Union Types

You can call service method with an instance of `TypeA`, `TypeB`, or a dictionary that can be converted to an instance of either type.

```python
# Model Definition
ParamType = Union[TypeA, TypeB]

# Service Method
def service_method(param: ParamType):
...

## Usage
type_a = TypeA(key="value")
type_b = TypeB(key="value")

sdk.service.service_method(type_a)
sdk.service.service_method(type_b)
sdk.service.service_method({"key": "value"})
```

You cannot create an instance of a `Union` type itself. Instead, pass an instance of one of the types in the `Union`, or a dictionary that can be converted to one of those types.

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                                                                 |
| :--------------------------------------------------------------------------------------------------- |
| [IncidentsService](documentation/services/IncidentsService.md)                                       |
| [CodmwLeaguesService](documentation/services/CodmwLeaguesService.md)                                 |
| [CodmwMatchesService](documentation/services/CodmwMatchesService.md)                                 |
| [CodmwPlayersService](documentation/services/CodmwPlayersService.md)                                 |
| [CodmwSeriesService](documentation/services/CodmwSeriesService.md)                                   |
| [CodmwTeamsService](documentation/services/CodmwTeamsService.md)                                     |
| [CodmwTournamentsService](documentation/services/CodmwTournamentsService.md)                         |
| [CounterStrikeGamesService](documentation/services/CounterStrikeGamesService.md)                     |
| [CounterStrikeLeaguesService](documentation/services/CounterStrikeLeaguesService.md)                 |
| [CounterStrikeMapsService](documentation/services/CounterStrikeMapsService.md)                       |
| [CounterStrikeMatchesService](documentation/services/CounterStrikeMatchesService.md)                 |
| [CounterStrikeStatsService](documentation/services/CounterStrikeStatsService.md)                     |
| [CounterStrikePlayersService](documentation/services/CounterStrikePlayersService.md)                 |
| [CounterStrikeSeriesService](documentation/services/CounterStrikeSeriesService.md)                   |
| [CounterStrikeTeamsService](documentation/services/CounterStrikeTeamsService.md)                     |
| [CounterStrikeTournamentsService](documentation/services/CounterStrikeTournamentsService.md)         |
| [CounterStrikeWeaponsService](documentation/services/CounterStrikeWeaponsService.md)                 |
| [Dota2AbilitiesService](documentation/services/Dota2AbilitiesService.md)                             |
| [Dota2GamesService](documentation/services/Dota2GamesService.md)                                     |
| [Dota2HeroesService](documentation/services/Dota2HeroesService.md)                                   |
| [Dota2ItemsService](documentation/services/Dota2ItemsService.md)                                     |
| [Dota2LeaguesService](documentation/services/Dota2LeaguesService.md)                                 |
| [Dota2MatchesService](documentation/services/Dota2MatchesService.md)                                 |
| [Dota2StatsService](documentation/services/Dota2StatsService.md)                                     |
| [Dota2PlayersService](documentation/services/Dota2PlayersService.md)                                 |
| [Dota2SeriesService](documentation/services/Dota2SeriesService.md)                                   |
| [Dota2TeamsService](documentation/services/Dota2TeamsService.md)                                     |
| [Dota2TournamentsService](documentation/services/Dota2TournamentsService.md)                         |
| [EaSportsFcLeaguesService](documentation/services/EaSportsFcLeaguesService.md)                       |
| [EaSportsFcMatchesService](documentation/services/EaSportsFcMatchesService.md)                       |
| [EaSportsFcPlayersService](documentation/services/EaSportsFcPlayersService.md)                       |
| [EaSportsFcSeriesService](documentation/services/EaSportsFcSeriesService.md)                         |
| [EaSportsFcTeamsService](documentation/services/EaSportsFcTeamsService.md)                           |
| [EaSportsFcTournamentsService](documentation/services/EaSportsFcTournamentsService.md)               |
| [KogLeaguesService](documentation/services/KogLeaguesService.md)                                     |
| [KogMatchesService](documentation/services/KogMatchesService.md)                                     |
| [KogPlayersService](documentation/services/KogPlayersService.md)                                     |
| [KogSeriesService](documentation/services/KogSeriesService.md)                                       |
| [KogTeamsService](documentation/services/KogTeamsService.md)                                         |
| [KogTournamentsService](documentation/services/KogTournamentsService.md)                             |
| [LeaguesService](documentation/services/LeaguesService.md)                                           |
| [LivesService](documentation/services/LivesService.md)                                               |
| [LoLWildRiftLeaguesService](documentation/services/LoLWildRiftLeaguesService.md)                     |
| [LoLWildRiftMatchesService](documentation/services/LoLWildRiftMatchesService.md)                     |
| [LoLWildRiftPlayersService](documentation/services/LoLWildRiftPlayersService.md)                     |
| [LoLWildRiftSeriesService](documentation/services/LoLWildRiftSeriesService.md)                       |
| [LoLWildRiftTeamsService](documentation/services/LoLWildRiftTeamsService.md)                         |
| [LoLWildRiftTournamentsService](documentation/services/LoLWildRiftTournamentsService.md)             |
| [LoLChampionsService](documentation/services/LoLChampionsService.md)                                 |
| [LoLGamesService](documentation/services/LoLGamesService.md)                                         |
| [LoLItemsService](documentation/services/LoLItemsService.md)                                         |
| [LoLLeaguesService](documentation/services/LoLLeaguesService.md)                                     |
| [LoLMasteriesService](documentation/services/LoLMasteriesService.md)                                 |
| [LoLMatchesService](documentation/services/LoLMatchesService.md)                                     |
| [LoLStatsService](documentation/services/LoLStatsService.md)                                         |
| [LoLPlayersService](documentation/services/LoLPlayersService.md)                                     |
| [LoLRunesService](documentation/services/LoLRunesService.md)                                         |
| [LoLSeriesService](documentation/services/LoLSeriesService.md)                                       |
| [LoLTeamsService](documentation/services/LoLTeamsService.md)                                         |
| [LoLSpellsService](documentation/services/LoLSpellsService.md)                                       |
| [LoLTournamentsService](documentation/services/LoLTournamentsService.md)                             |
| [MatchesService](documentation/services/MatchesService.md)                                           |
| [OwGamesService](documentation/services/OwGamesService.md)                                           |
| [OwStatsService](documentation/services/OwStatsService.md)                                           |
| [OwHeroesService](documentation/services/OwHeroesService.md)                                         |
| [OwLeaguesService](documentation/services/OwLeaguesService.md)                                       |
| [OwMapsService](documentation/services/OwMapsService.md)                                             |
| [OwMatchesService](documentation/services/OwMatchesService.md)                                       |
| [OwPlayersService](documentation/services/OwPlayersService.md)                                       |
| [OwSeriesService](documentation/services/OwSeriesService.md)                                         |
| [OwTeamsService](documentation/services/OwTeamsService.md)                                           |
| [OwTournamentsService](documentation/services/OwTournamentsService.md)                               |
| [PlayersService](documentation/services/PlayersService.md)                                           |
| [PubgLeaguesService](documentation/services/PubgLeaguesService.md)                                   |
| [PubgMatchesService](documentation/services/PubgMatchesService.md)                                   |
| [PubgPlayersService](documentation/services/PubgPlayersService.md)                                   |
| [PubgSeriesService](documentation/services/PubgSeriesService.md)                                     |
| [PubgTeamsService](documentation/services/PubgTeamsService.md)                                       |
| [PubgTournamentsService](documentation/services/PubgTournamentsService.md)                           |
| [R6SiegeLeaguesService](documentation/services/R6SiegeLeaguesService.md)                             |
| [R6SiegeMatchesService](documentation/services/R6SiegeMatchesService.md)                             |
| [R6SiegePlayersService](documentation/services/R6SiegePlayersService.md)                             |
| [R6SiegeSeriesService](documentation/services/R6SiegeSeriesService.md)                               |
| [R6SiegeTeamsService](documentation/services/R6SiegeTeamsService.md)                                 |
| [R6SiegeTournamentsService](documentation/services/R6SiegeTournamentsService.md)                     |
| [RlLeaguesService](documentation/services/RlLeaguesService.md)                                       |
| [RlMatchesService](documentation/services/RlMatchesService.md)                                       |
| [RlPlayersService](documentation/services/RlPlayersService.md)                                       |
| [RlSeriesService](documentation/services/RlSeriesService.md)                                         |
| [RlTeamsService](documentation/services/RlTeamsService.md)                                           |
| [RlTournamentsService](documentation/services/RlTournamentsService.md)                               |
| [SeriesService](documentation/services/SeriesService.md)                                             |
| [StarCraft2LeaguesService](documentation/services/StarCraft2LeaguesService.md)                       |
| [StarCraft2MatchesService](documentation/services/StarCraft2MatchesService.md)                       |
| [StarCraft2PlayersService](documentation/services/StarCraft2PlayersService.md)                       |
| [StarCraft2SeriesService](documentation/services/StarCraft2SeriesService.md)                         |
| [StarCraft2TeamsService](documentation/services/StarCraft2TeamsService.md)                           |
| [StarCraft2TournamentsService](documentation/services/StarCraft2TournamentsService.md)               |
| [StarCraftBroodWarLeaguesService](documentation/services/StarCraftBroodWarLeaguesService.md)         |
| [StarCraftBroodWarMatchesService](documentation/services/StarCraftBroodWarMatchesService.md)         |
| [StarCraftBroodWarPlayersService](documentation/services/StarCraftBroodWarPlayersService.md)         |
| [StarCraftBroodWarSeriesService](documentation/services/StarCraftBroodWarSeriesService.md)           |
| [StarCraftBroodWarTeamsService](documentation/services/StarCraftBroodWarTeamsService.md)             |
| [StarCraftBroodWarTournamentsService](documentation/services/StarCraftBroodWarTournamentsService.md) |
| [TeamsService](documentation/services/TeamsService.md)                                               |
| [TournamentsService](documentation/services/TournamentsService.md)                                   |
| [ValorantAbilitiesService](documentation/services/ValorantAbilitiesService.md)                       |
| [ValorantAgentsService](documentation/services/ValorantAgentsService.md)                             |
| [ValorantGamesService](documentation/services/ValorantGamesService.md)                               |
| [ValorantLeaguesService](documentation/services/ValorantLeaguesService.md)                           |
| [ValorantMapsService](documentation/services/ValorantMapsService.md)                                 |
| [ValorantMatchesService](documentation/services/ValorantMatchesService.md)                           |
| [ValorantStatsService](documentation/services/ValorantStatsService.md)                               |
| [ValorantPlayersService](documentation/services/ValorantPlayersService.md)                           |
| [ValorantSeriesService](documentation/services/ValorantSeriesService.md)                             |
| [ValorantTeamsService](documentation/services/ValorantTeamsService.md)                               |
| [ValorantTournamentsService](documentation/services/ValorantTournamentsService.md)                   |
| [ValorantWeaponsService](documentation/services/ValorantWeaponsService.md)                           |
| [VideogamesService](documentation/services/VideogamesService.md)                                     |

</details>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                                               | Description                                                                                                                                                                                                                                                                                      |
| :----------------------------------------------------------------------------------------------------------------- | :----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [NonDeletionIncident](documentation/models/NonDeletionIncident.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverAdditionIncidents](documentation/models/FilterOverAdditionIncidents.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverAdditionIncidents](documentation/models/RangeOverAdditionIncidents.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverChangeIncidents](documentation/models/FilterOverChangeIncidents.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverChangeIncidents](documentation/models/RangeOverChangeIncidents.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [DeletionIncident](documentation/models/DeletionIncident.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDeletionIncidents](documentation/models/FilterOverDeletionIncidents.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDeletionIncidents](documentation/models/RangeOverDeletionIncidents.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverIncidents](documentation/models/FilterOverIncidents.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverIncidents](documentation/models/RangeOverIncidents.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [League](documentation/models/League.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCodmwLeagues](documentation/models/FilterOverCodmwLeagues.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwLeagues](documentation/models/RangeOverCodmwLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwLeagues](documentation/models/SearchOverCodmwLeagues.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Match](documentation/models/Match.md)                                                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCodmwMatches](documentation/models/FilterOverCodmwMatches.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwMatches](documentation/models/RangeOverCodmwMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwMatches](documentation/models/SearchOverCodmwMatches.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Player](documentation/models/Player.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCodmwPlayers](documentation/models/FilterOverCodmwPlayers.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwPlayers](documentation/models/RangeOverCodmwPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwPlayers](documentation/models/SearchOverCodmwPlayers.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Serie](documentation/models/Serie.md)                                                                             | A serie, an occurrence of a league event                                                                                                                                                                                                                                                         |
| [FilterOverCodmwSeries](documentation/models/FilterOverCodmwSeries.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwSeries](documentation/models/RangeOverCodmwSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwSeries](documentation/models/SearchOverCodmwSeries.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [Team](documentation/models/Team.md)                                                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCodmwTeams](documentation/models/FilterOverCodmwTeams.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwTeams](documentation/models/RangeOverCodmwTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwTeams](documentation/models/SearchOverCodmwTeams.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [ShortTournament](documentation/models/ShortTournament.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCodmwShortTournaments](documentation/models/FilterOverCodmwShortTournaments.md)                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCodmwShortTournaments](documentation/models/RangeOverCodmwShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCodmwShortTournaments](documentation/models/SearchOverCodmwShortTournaments.md)                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoGame](documentation/models/CsgoGame.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [CsgoEvent](documentation/models/CsgoEvent.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRound](documentation/models/CsgoFullRound.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoGames](documentation/models/FilterOverCsgoGames.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoGames](documentation/models/RangeOverCsgoGames.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoGames](documentation/models/SearchOverCsgoGames.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoLeagues](documentation/models/FilterOverCsgoLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoLeagues](documentation/models/RangeOverCsgoLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoLeagues](documentation/models/SearchOverCsgoLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoMap](documentation/models/CsgoMap.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoMaps](documentation/models/FilterOverCsgoMaps.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoMaps](documentation/models/RangeOverCsgoMaps.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoMaps](documentation/models/SearchOverCsgoMaps.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoMatches](documentation/models/FilterOverCsgoMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoMatches](documentation/models/RangeOverCsgoMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoMatches](documentation/models/SearchOverCsgoMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatch](documentation/models/CsgoMatch.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsForAllPlayersByMatch](documentation/models/CsgoStatsForAllPlayersByMatch.md)                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsForPlayerByMatch](documentation/models/CsgoStatsForPlayerByMatch.md)                                     | Player's aggregated statistics for a match                                                                                                                                                                                                                                                       |
| [CsgoStatsForTeamByMatch](documentation/models/CsgoStatsForTeamByMatch.md)                                         | Team's aggregated statistics for a match                                                                                                                                                                                                                                                         |
| [CsgoStatsForPlayer](documentation/models/CsgoStatsForPlayer.md)                                                   | Player's aggregated statistics                                                                                                                                                                                                                                                                   |
| [CsgoStatsForPlayerBySerie](documentation/models/CsgoStatsForPlayerBySerie.md)                                     | Player's aggregated statistics for a serie                                                                                                                                                                                                                                                       |
| [CsgoStatsForTeamBySerie](documentation/models/CsgoStatsForTeamBySerie.md)                                         | Team's aggregated statistics for a serie                                                                                                                                                                                                                                                         |
| [CsgoStatsForTeam](documentation/models/CsgoStatsForTeam.md)                                                       | Team's aggregated statistics                                                                                                                                                                                                                                                                     |
| [CsgoStatsForPlayerByTournament](documentation/models/CsgoStatsForPlayerByTournament.md)                           | Player's aggregated statistics for a tournament                                                                                                                                                                                                                                                  |
| [CsgoStatsForTeamByTournament](documentation/models/CsgoStatsForTeamByTournament.md)                               | Team's aggregated statistics for a tournament                                                                                                                                                                                                                                                    |
| [FilterOverCsgoPlayers](documentation/models/FilterOverCsgoPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoPlayers](documentation/models/RangeOverCsgoPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoPlayers](documentation/models/SearchOverCsgoPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoSeries](documentation/models/FilterOverCsgoSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoSeries](documentation/models/RangeOverCsgoSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoSeries](documentation/models/SearchOverCsgoSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoTeams](documentation/models/FilterOverCsgoTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoTeams](documentation/models/RangeOverCsgoTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoTeams](documentation/models/SearchOverCsgoTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoShortTournaments](documentation/models/FilterOverCsgoShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoShortTournaments](documentation/models/RangeOverCsgoShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoShortTournaments](documentation/models/SearchOverCsgoShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [CsgoWeapon](documentation/models/CsgoWeapon.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverCsgoWeapons](documentation/models/FilterOverCsgoWeapons.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverCsgoWeapons](documentation/models/RangeOverCsgoWeapons.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverCsgoWeapons](documentation/models/SearchOverCsgoWeapons.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [Dota2Ability](documentation/models/Dota2Ability.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Abilities](documentation/models/FilterOverDota2Abilities.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Abilities](documentation/models/RangeOverDota2Abilities.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Abilities](documentation/models/SearchOverDota2Abilities.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [Dota2Game](documentation/models/Dota2Game.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [Dota2Frame](documentation/models/Dota2Frame.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Games](documentation/models/FilterOverDota2Games.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Games](documentation/models/RangeOverDota2Games.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Games](documentation/models/SearchOverDota2Games.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [BaseDota2Game](documentation/models/BaseDota2Game.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [Dota2Hero](documentation/models/Dota2Hero.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Heroes](documentation/models/FilterOverDota2Heroes.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Heroes](documentation/models/RangeOverDota2Heroes.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Heroes](documentation/models/SearchOverDota2Heroes.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [Dota2Item](documentation/models/Dota2Item.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Items](documentation/models/FilterOverDota2Items.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Items](documentation/models/RangeOverDota2Items.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Items](documentation/models/SearchOverDota2Items.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Leagues](documentation/models/FilterOverDota2Leagues.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Leagues](documentation/models/RangeOverDota2Leagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Leagues](documentation/models/SearchOverDota2Leagues.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Matches](documentation/models/FilterOverDota2Matches.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Matches](documentation/models/RangeOverDota2Matches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Matches](documentation/models/SearchOverDota2Matches.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2StatsForAllPlayersByMatch](documentation/models/Dota2StatsForAllPlayersByMatch.md)                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2StatsForPlayer](documentation/models/Dota2StatsForPlayer.md)                                                 | Aggregated statistics for a player grouped by serie                                                                                                                                                                                                                                              |
| [GetDota2PlayersPlayerIdOrSlugStatsSide](documentation/models/GetDota2PlayersPlayerIdOrSlugStatsSide.md)           |                                                                                                                                                                                                                                                                                                  |
| [Dota2StatsForPlayerBySerie](documentation/models/Dota2StatsForPlayerBySerie.md)                                   | Player's aggregated statistics for a serie                                                                                                                                                                                                                                                       |
| [Dota2StatsForTeamBySerie](documentation/models/Dota2StatsForTeamBySerie.md)                                       | Team's aggregated statistics for a serie                                                                                                                                                                                                                                                         |
| [Dota2StatsForTeam](documentation/models/Dota2StatsForTeam.md)                                                     | Aggregated statistics for a team grouped by serie                                                                                                                                                                                                                                                |
| [Dota2StatsForPlayerByTournament](documentation/models/Dota2StatsForPlayerByTournament.md)                         | Player's aggregated statistics for a tournament                                                                                                                                                                                                                                                  |
| [Dota2StatsForTeamByTournament](documentation/models/Dota2StatsForTeamByTournament.md)                             | Team's aggregated statistics for a tournament                                                                                                                                                                                                                                                    |
| [FilterOverDota2Players](documentation/models/FilterOverDota2Players.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Players](documentation/models/RangeOverDota2Players.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Players](documentation/models/SearchOverDota2Players.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Series](documentation/models/FilterOverDota2Series.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Series](documentation/models/RangeOverDota2Series.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Series](documentation/models/SearchOverDota2Series.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2Teams](documentation/models/FilterOverDota2Teams.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2Teams](documentation/models/RangeOverDota2Teams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2Teams](documentation/models/SearchOverDota2Teams.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverDota2ShortTournaments](documentation/models/FilterOverDota2ShortTournaments.md)                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverDota2ShortTournaments](documentation/models/RangeOverDota2ShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverDota2ShortTournaments](documentation/models/SearchOverDota2ShortTournaments.md)                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaLeagues](documentation/models/FilterOverFifaLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaLeagues](documentation/models/RangeOverFifaLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaLeagues](documentation/models/SearchOverFifaLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaMatches](documentation/models/FilterOverFifaMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaMatches](documentation/models/RangeOverFifaMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaMatches](documentation/models/SearchOverFifaMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaPlayers](documentation/models/FilterOverFifaPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaPlayers](documentation/models/RangeOverFifaPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaPlayers](documentation/models/SearchOverFifaPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaSeries](documentation/models/FilterOverFifaSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaSeries](documentation/models/RangeOverFifaSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaSeries](documentation/models/SearchOverFifaSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaTeams](documentation/models/FilterOverFifaTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaTeams](documentation/models/RangeOverFifaTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaTeams](documentation/models/SearchOverFifaTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverFifaShortTournaments](documentation/models/FilterOverFifaShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverFifaShortTournaments](documentation/models/RangeOverFifaShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverFifaShortTournaments](documentation/models/SearchOverFifaShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogLeagues](documentation/models/FilterOverKogLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogLeagues](documentation/models/RangeOverKogLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogLeagues](documentation/models/SearchOverKogLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogMatches](documentation/models/FilterOverKogMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogMatches](documentation/models/RangeOverKogMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogMatches](documentation/models/SearchOverKogMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogPlayers](documentation/models/FilterOverKogPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogPlayers](documentation/models/RangeOverKogPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogPlayers](documentation/models/SearchOverKogPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogSeries](documentation/models/FilterOverKogSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogSeries](documentation/models/RangeOverKogSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogSeries](documentation/models/SearchOverKogSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogTeams](documentation/models/FilterOverKogTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogTeams](documentation/models/RangeOverKogTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogTeams](documentation/models/SearchOverKogTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverKogShortTournaments](documentation/models/FilterOverKogShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverKogShortTournaments](documentation/models/RangeOverKogShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverKogShortTournaments](documentation/models/SearchOverKogShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLeagues](documentation/models/FilterOverLeagues.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLeagues](documentation/models/RangeOverLeagues.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLeagues](documentation/models/SearchOverLeagues.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverMatches](documentation/models/FilterOverMatches.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverMatches](documentation/models/RangeOverMatches.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverMatches](documentation/models/SearchOverMatches.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverSeries](documentation/models/FilterOverSeries.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverSeries](documentation/models/RangeOverSeries.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverSeries](documentation/models/SearchOverSeries.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverShortTournaments](documentation/models/FilterOverShortTournaments.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverShortTournaments](documentation/models/RangeOverShortTournaments.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverShortTournaments](documentation/models/SearchOverShortTournaments.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [Live](documentation/models/Live.md)                                                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftLeagues](documentation/models/FilterOverLolWildRiftLeagues.md)                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftLeagues](documentation/models/RangeOverLolWildRiftLeagues.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftLeagues](documentation/models/SearchOverLolWildRiftLeagues.md)                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftMatches](documentation/models/FilterOverLolWildRiftMatches.md)                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftMatches](documentation/models/RangeOverLolWildRiftMatches.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftMatches](documentation/models/SearchOverLolWildRiftMatches.md)                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftPlayers](documentation/models/FilterOverLolWildRiftPlayers.md)                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftPlayers](documentation/models/RangeOverLolWildRiftPlayers.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftPlayers](documentation/models/SearchOverLolWildRiftPlayers.md)                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftSeries](documentation/models/FilterOverLolWildRiftSeries.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftSeries](documentation/models/RangeOverLolWildRiftSeries.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftSeries](documentation/models/SearchOverLolWildRiftSeries.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftTeams](documentation/models/FilterOverLolWildRiftTeams.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftTeams](documentation/models/RangeOverLolWildRiftTeams.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftTeams](documentation/models/SearchOverLolWildRiftTeams.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLolWildRiftShortTournaments](documentation/models/FilterOverLolWildRiftShortTournaments.md)             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLolWildRiftShortTournaments](documentation/models/RangeOverLolWildRiftShortTournaments.md)               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLolWildRiftShortTournaments](documentation/models/SearchOverLolWildRiftShortTournaments.md)             |                                                                                                                                                                                                                                                                                                  |
| [LoLChampion](documentation/models/LoLChampion.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLChampions](documentation/models/FilterOverLoLChampions.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLChampions](documentation/models/RangeOverLoLChampions.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLChampions](documentation/models/SearchOverLoLChampions.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLGame](documentation/models/LoLGame.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLGameEvent](documentation/models/LoLGameEvent.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLGameFrame](documentation/models/LoLGameFrame.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLGames](documentation/models/FilterOverLoLGames.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLGames](documentation/models/RangeOverLoLGames.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLGames](documentation/models/SearchOverLoLGames.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamLastGame](documentation/models/LoLTeamLastGame.md)                                                         | A team's last game                                                                                                                                                                                                                                                                               |
| [FilterOverLoLTeamLastGames](documentation/models/FilterOverLoLTeamLastGames.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLTeamLastGames](documentation/models/RangeOverLoLTeamLastGames.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLTeamLastGames](documentation/models/SearchOverLoLTeamLastGames.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLItem](documentation/models/LoLItem.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLItems](documentation/models/FilterOverLoLItems.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLItems](documentation/models/RangeOverLoLItems.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLItems](documentation/models/SearchOverLoLItems.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLLeagues](documentation/models/FilterOverLoLLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLLeagues](documentation/models/RangeOverLoLLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLLeagues](documentation/models/SearchOverLoLLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLMastery](documentation/models/LoLMastery.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLMasteries](documentation/models/FilterOverLoLMasteries.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLMasteries](documentation/models/RangeOverLoLMasteries.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLMasteries](documentation/models/SearchOverLoLMasteries.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLMatches](documentation/models/FilterOverLoLMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLMatches](documentation/models/RangeOverLoLMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLMatches](documentation/models/SearchOverLoLMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLMatch](documentation/models/LoLMatch.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLStatsForAllPlayersByMatch](documentation/models/LoLStatsForAllPlayersByMatch.md)                               |                                                                                                                                                                                                                                                                                                  |
| [LoLStatsForPlayer](documentation/models/LoLStatsForPlayer.md)                                                     | Aggregated statistics for a player grouped by serie                                                                                                                                                                                                                                              |
| [GetLolPlayersPlayerIdOrSlugStatsSide](documentation/models/GetLolPlayersPlayerIdOrSlugStatsSide.md)               |                                                                                                                                                                                                                                                                                                  |
| [LoLStatsForPlayerBySerie](documentation/models/LoLStatsForPlayerBySerie.md)                                       | Player's aggregated statistics for a serie                                                                                                                                                                                                                                                       |
| [LoLStatsForTeamBySerie](documentation/models/LoLStatsForTeamBySerie.md)                                           | Team's aggregated statistics for a serie                                                                                                                                                                                                                                                         |
| [LoLStatsForTeam](documentation/models/LoLStatsForTeam.md)                                                         | Aggregated statistics for a team grouped by serie                                                                                                                                                                                                                                                |
| [LoLStatsForPlayerByTournament](documentation/models/LoLStatsForPlayerByTournament.md)                             | Player's aggregated statistics for a tournament                                                                                                                                                                                                                                                  |
| [LoLStatsForTeamByTournament](documentation/models/LoLStatsForTeamByTournament.md)                                 | Team's aggregated statistics for a tournament                                                                                                                                                                                                                                                    |
| [FilterOverLoLPlayers](documentation/models/FilterOverLoLPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLPlayers](documentation/models/RangeOverLoLPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLPlayers](documentation/models/SearchOverLoLPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLRune](documentation/models/LoLRune.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLRunes](documentation/models/FilterOverLoLRunes.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLRunes](documentation/models/RangeOverLoLRunes.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLRunes](documentation/models/SearchOverLoLRunes.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLRuneReforged](documentation/models/LoLRuneReforged.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLRunesReforged](documentation/models/FilterOverLoLRunesReforged.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLRunesReforged](documentation/models/RangeOverLoLRunesReforged.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLRunesReforged](documentation/models/SearchOverLoLRunesReforged.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLRunePath](documentation/models/LoLRunePath.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLRunePaths](documentation/models/FilterOverLoLRunePaths.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLRunePaths](documentation/models/RangeOverLoLRunePaths.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLRunePaths](documentation/models/SearchOverLoLRunePaths.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLSeries](documentation/models/FilterOverLoLSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLSeries](documentation/models/RangeOverLoLSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLSeries](documentation/models/SearchOverLoLSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLTeams](documentation/models/FilterOverLoLTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLTeams](documentation/models/RangeOverLoLTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLTeams](documentation/models/SearchOverLoLTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLSpell](documentation/models/LoLSpell.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLSpells](documentation/models/FilterOverLoLSpells.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLSpells](documentation/models/RangeOverLoLSpells.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLSpells](documentation/models/SearchOverLoLSpells.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverLoLShortTournaments](documentation/models/FilterOverLoLShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverLoLShortTournaments](documentation/models/RangeOverLoLShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverLoLShortTournaments](documentation/models/SearchOverLoLShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [OwGame](documentation/models/OwGame.md)                                                                           | A game                                                                                                                                                                                                                                                                                           |
| [FilterOverOwGames](documentation/models/FilterOverOwGames.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwGames](documentation/models/RangeOverOwGames.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwGames](documentation/models/SearchOverOwGames.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerByGame](documentation/models/OwStatsForPlayerByGame.md)                                           | Player's aggregated statistics for a game                                                                                                                                                                                                                                                        |
| [OwStatsForAllPlayersByMatch](documentation/models/OwStatsForAllPlayersByMatch.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerByMatch](documentation/models/OwStatsForPlayerByMatch.md)                                         | Player's aggregated statistics for a match                                                                                                                                                                                                                                                       |
| [OwStatsForPlayer](documentation/models/OwStatsForPlayer.md)                                                       | Aggregated statistics for a player                                                                                                                                                                                                                                                               |
| [OwStatsForPlayerBySerie](documentation/models/OwStatsForPlayerBySerie.md)                                         | Player's aggregated statistics for a serie                                                                                                                                                                                                                                                       |
| [OwStatsForPlayerByTournament](documentation/models/OwStatsForPlayerByTournament.md)                               | Player's aggregated statistics for a tournament                                                                                                                                                                                                                                                  |
| [OwHero](documentation/models/OwHero.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwHeroes](documentation/models/FilterOverOwHeroes.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwHeroes](documentation/models/RangeOverOwHeroes.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwHeroes](documentation/models/SearchOverOwHeroes.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwLeagues](documentation/models/FilterOverOwLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwLeagues](documentation/models/RangeOverOwLeagues.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwLeagues](documentation/models/SearchOverOwLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [OwMap](documentation/models/OwMap.md)                                                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwMaps](documentation/models/FilterOverOwMaps.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwMaps](documentation/models/RangeOverOwMaps.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwMaps](documentation/models/SearchOverOwMaps.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwMatches](documentation/models/FilterOverOwMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwMatches](documentation/models/RangeOverOwMatches.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwMatches](documentation/models/SearchOverOwMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwPlayers](documentation/models/FilterOverOwPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwPlayers](documentation/models/RangeOverOwPlayers.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwPlayers](documentation/models/SearchOverOwPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwSeries](documentation/models/FilterOverOwSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwSeries](documentation/models/RangeOverOwSeries.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwSeries](documentation/models/SearchOverOwSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwTeams](documentation/models/FilterOverOwTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwTeams](documentation/models/RangeOverOwTeams.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwTeams](documentation/models/SearchOverOwTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverOwShortTournaments](documentation/models/FilterOverOwShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverOwShortTournaments](documentation/models/RangeOverOwShortTournaments.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverOwShortTournaments](documentation/models/SearchOverOwShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPlayers](documentation/models/FilterOverPlayers.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPlayers](documentation/models/RangeOverPlayers.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPlayers](documentation/models/SearchOverPlayers.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgLeagues](documentation/models/FilterOverPubgLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgLeagues](documentation/models/RangeOverPubgLeagues.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgLeagues](documentation/models/SearchOverPubgLeagues.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgMatches](documentation/models/FilterOverPubgMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgMatches](documentation/models/RangeOverPubgMatches.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgMatches](documentation/models/SearchOverPubgMatches.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgPlayers](documentation/models/FilterOverPubgPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgPlayers](documentation/models/RangeOverPubgPlayers.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgPlayers](documentation/models/SearchOverPubgPlayers.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgSeries](documentation/models/FilterOverPubgSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgSeries](documentation/models/RangeOverPubgSeries.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgSeries](documentation/models/SearchOverPubgSeries.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgTeams](documentation/models/FilterOverPubgTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgTeams](documentation/models/RangeOverPubgTeams.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgTeams](documentation/models/SearchOverPubgTeams.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverPubgShortTournaments](documentation/models/FilterOverPubgShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverPubgShortTournaments](documentation/models/RangeOverPubgShortTournaments.md)                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverPubgShortTournaments](documentation/models/SearchOverPubgShortTournaments.md)                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegeLeagues](documentation/models/FilterOverR6SiegeLeagues.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegeLeagues](documentation/models/RangeOverR6SiegeLeagues.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegeLeagues](documentation/models/SearchOverR6SiegeLeagues.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegeMatches](documentation/models/FilterOverR6SiegeMatches.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegeMatches](documentation/models/RangeOverR6SiegeMatches.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegeMatches](documentation/models/SearchOverR6SiegeMatches.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegePlayers](documentation/models/FilterOverR6SiegePlayers.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegePlayers](documentation/models/RangeOverR6SiegePlayers.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegePlayers](documentation/models/SearchOverR6SiegePlayers.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegeSeries](documentation/models/FilterOverR6SiegeSeries.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegeSeries](documentation/models/RangeOverR6SiegeSeries.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegeSeries](documentation/models/SearchOverR6SiegeSeries.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegeTeams](documentation/models/FilterOverR6SiegeTeams.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegeTeams](documentation/models/RangeOverR6SiegeTeams.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegeTeams](documentation/models/SearchOverR6SiegeTeams.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverR6SiegeShortTournaments](documentation/models/FilterOverR6SiegeShortTournaments.md)                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverR6SiegeShortTournaments](documentation/models/RangeOverR6SiegeShortTournaments.md)                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverR6SiegeShortTournaments](documentation/models/SearchOverR6SiegeShortTournaments.md)                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlLeagues](documentation/models/FilterOverRlLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlLeagues](documentation/models/RangeOverRlLeagues.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlLeagues](documentation/models/SearchOverRlLeagues.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlMatches](documentation/models/FilterOverRlMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlMatches](documentation/models/RangeOverRlMatches.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlMatches](documentation/models/SearchOverRlMatches.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlPlayers](documentation/models/FilterOverRlPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlPlayers](documentation/models/RangeOverRlPlayers.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlPlayers](documentation/models/SearchOverRlPlayers.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlSeries](documentation/models/FilterOverRlSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlSeries](documentation/models/RangeOverRlSeries.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlSeries](documentation/models/SearchOverRlSeries.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlTeams](documentation/models/FilterOverRlTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlTeams](documentation/models/RangeOverRlTeams.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlTeams](documentation/models/SearchOverRlTeams.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverRlShortTournaments](documentation/models/FilterOverRlShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverRlShortTournaments](documentation/models/RangeOverRlShortTournaments.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverRlShortTournaments](documentation/models/SearchOverRlShortTournaments.md)                               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2Leagues](documentation/models/FilterOverStarcraft2Leagues.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2Leagues](documentation/models/RangeOverStarcraft2Leagues.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2Leagues](documentation/models/SearchOverStarcraft2Leagues.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2Matches](documentation/models/FilterOverStarcraft2Matches.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2Matches](documentation/models/RangeOverStarcraft2Matches.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2Matches](documentation/models/SearchOverStarcraft2Matches.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2Players](documentation/models/FilterOverStarcraft2Players.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2Players](documentation/models/RangeOverStarcraft2Players.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2Players](documentation/models/SearchOverStarcraft2Players.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2Series](documentation/models/FilterOverStarcraft2Series.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2Series](documentation/models/RangeOverStarcraft2Series.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2Series](documentation/models/SearchOverStarcraft2Series.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2Teams](documentation/models/FilterOverStarcraft2Teams.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2Teams](documentation/models/RangeOverStarcraft2Teams.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2Teams](documentation/models/SearchOverStarcraft2Teams.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraft2ShortTournaments](documentation/models/FilterOverStarcraft2ShortTournaments.md)               |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraft2ShortTournaments](documentation/models/RangeOverStarcraft2ShortTournaments.md)                 |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraft2ShortTournaments](documentation/models/SearchOverStarcraft2ShortTournaments.md)               |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarLeagues](documentation/models/FilterOverStarcraftBroodWarLeagues.md)                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarLeagues](documentation/models/RangeOverStarcraftBroodWarLeagues.md)                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarLeagues](documentation/models/SearchOverStarcraftBroodWarLeagues.md)                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarMatches](documentation/models/FilterOverStarcraftBroodWarMatches.md)                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarMatches](documentation/models/RangeOverStarcraftBroodWarMatches.md)                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarMatches](documentation/models/SearchOverStarcraftBroodWarMatches.md)                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarPlayers](documentation/models/FilterOverStarcraftBroodWarPlayers.md)                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarPlayers](documentation/models/RangeOverStarcraftBroodWarPlayers.md)                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarPlayers](documentation/models/SearchOverStarcraftBroodWarPlayers.md)                   |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarSeries](documentation/models/FilterOverStarcraftBroodWarSeries.md)                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarSeries](documentation/models/RangeOverStarcraftBroodWarSeries.md)                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarSeries](documentation/models/SearchOverStarcraftBroodWarSeries.md)                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarTeams](documentation/models/FilterOverStarcraftBroodWarTeams.md)                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarTeams](documentation/models/RangeOverStarcraftBroodWarTeams.md)                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarTeams](documentation/models/SearchOverStarcraftBroodWarTeams.md)                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverStarcraftBroodWarShortTournaments](documentation/models/FilterOverStarcraftBroodWarShortTournaments.md) |                                                                                                                                                                                                                                                                                                  |
| [RangeOverStarcraftBroodWarShortTournaments](documentation/models/RangeOverStarcraftBroodWarShortTournaments.md)   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverStarcraftBroodWarShortTournaments](documentation/models/SearchOverStarcraftBroodWarShortTournaments.md) |                                                                                                                                                                                                                                                                                                  |
| [FilterOverTeams](documentation/models/FilterOverTeams.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverTeams](documentation/models/RangeOverTeams.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverTeams](documentation/models/SearchOverTeams.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [Tournament](documentation/models/Tournament.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [Bracket](documentation/models/Bracket.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverBrackets](documentation/models/FilterOverBrackets.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverBrackets](documentation/models/RangeOverBrackets.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverBrackets](documentation/models/SearchOverBrackets.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantAbility](documentation/models/ValorantAbility.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantAbilities](documentation/models/FilterOverValorantAbilities.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantAbilities](documentation/models/RangeOverValorantAbilities.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantAbilities](documentation/models/SearchOverValorantAbilities.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [ValorantAgent](documentation/models/ValorantAgent.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantAgents](documentation/models/FilterOverValorantAgents.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantAgents](documentation/models/RangeOverValorantAgents.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantAgents](documentation/models/SearchOverValorantAgents.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [ValorantGame](documentation/models/ValorantGame.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [ValorantGameEvent](documentation/models/ValorantGameEvent.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantFullRound](documentation/models/ValorantFullRound.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantGames](documentation/models/FilterOverValorantGames.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantGames](documentation/models/RangeOverValorantGames.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantGames](documentation/models/SearchOverValorantGames.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantLeagues](documentation/models/FilterOverValorantLeagues.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantLeagues](documentation/models/RangeOverValorantLeagues.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantLeagues](documentation/models/SearchOverValorantLeagues.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantMap](documentation/models/ValorantMap.md)                                                                 | An object that represents a Valorant map                                                                                                                                                                                                                                                         |
| [FilterOverValorantMaps](documentation/models/FilterOverValorantMaps.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantMaps](documentation/models/RangeOverValorantMaps.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantMaps](documentation/models/SearchOverValorantMaps.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantMatches](documentation/models/FilterOverValorantMatches.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantMatches](documentation/models/RangeOverValorantMatches.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantMatches](documentation/models/SearchOverValorantMatches.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForPlayersByMatch](documentation/models/ValorantStatsForPlayersByMatch.md)                           |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForTeamByMatch](documentation/models/ValorantStatsForTeamByMatch.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForPlayer](documentation/models/ValorantStatsForPlayer.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForPlayerBySerie](documentation/models/ValorantStatsForPlayerBySerie.md)                             |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForTeamBySerie](documentation/models/ValorantStatsForTeamBySerie.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForTeam](documentation/models/ValorantStatsForTeam.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForPlayerByTournament](documentation/models/ValorantStatsForPlayerByTournament.md)                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantStatsForTeamByTournament](documentation/models/ValorantStatsForTeamByTournament.md)                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantPlayers](documentation/models/FilterOverValorantPlayers.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantPlayers](documentation/models/RangeOverValorantPlayers.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantPlayers](documentation/models/SearchOverValorantPlayers.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantSeries](documentation/models/FilterOverValorantSeries.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantSeries](documentation/models/RangeOverValorantSeries.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantSeries](documentation/models/SearchOverValorantSeries.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantTeams](documentation/models/FilterOverValorantTeams.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantTeams](documentation/models/RangeOverValorantTeams.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantTeams](documentation/models/SearchOverValorantTeams.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantShortTournaments](documentation/models/FilterOverValorantShortTournaments.md)                   |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantShortTournaments](documentation/models/RangeOverValorantShortTournaments.md)                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantShortTournaments](documentation/models/SearchOverValorantShortTournaments.md)                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantWeapon](documentation/models/ValorantWeapon.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [FilterOverValorantWeapons](documentation/models/FilterOverValorantWeapons.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [RangeOverValorantWeapons](documentation/models/RangeOverValorantWeapons.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantWeapons](documentation/models/SearchOverValorantWeapons.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ShortVideogameTitle](documentation/models/ShortVideogameTitle.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [ShortVideogameVersion](documentation/models/ShortVideogameVersion.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [IncidentChangeType](documentation/models/IncidentChangeType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [IncidentId](documentation/models/IncidentId.md)                                                                   | An incident ID                                                                                                                                                                                                                                                                                   |
| [IncidentType](documentation/models/IncidentType.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [BaseSerie](documentation/models/BaseSerie.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [BaseSerieWinnerId](documentation/models/BaseSerieWinnerId.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [BaseSerieWinnerType](documentation/models/BaseSerieWinnerType.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameLoL](documentation/models/LeagueVideogameLoL.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameCsgo](documentation/models/LeagueVideogameCsgo.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameDota2](documentation/models/LeagueVideogameDota2.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameOverwatch](documentation/models/LeagueVideogameOverwatch.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogamePubg](documentation/models/LeagueVideogamePubg.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameRocketLeague](documentation/models/LeagueVideogameRocketLeague.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameCodmw](documentation/models/LeagueVideogameCodmw.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameR6siege](documentation/models/LeagueVideogameR6siege.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameFifa](documentation/models/LeagueVideogameFifa.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameValorant](documentation/models/LeagueVideogameValorant.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameKog](documentation/models/LeagueVideogameKog.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameLolWildRift](documentation/models/LeagueVideogameLolWildRift.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameStarcraft2](documentation/models/LeagueVideogameStarcraft2.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameStarcraftBroodWar](documentation/models/LeagueVideogameStarcraftBroodWar.md)                       |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameEBasketball](documentation/models/LeagueVideogameEBasketball.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameECricket](documentation/models/LeagueVideogameECricket.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [LeagueVideogameESoccer](documentation/models/LeagueVideogameESoccer.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [BaseLeague](documentation/models/BaseLeague.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [BaseTournament](documentation/models/BaseTournament.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [SerieVideogameTitle](documentation/models/SerieVideogameTitle.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [SerieWinnerId](documentation/models/SerieWinnerId.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [SerieWinnerType](documentation/models/SerieWinnerType.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [BaseTournamentTier](documentation/models/BaseTournamentTier.md)                                                   | The tier of the tournament, ranging from 'S' to 'Unranked'. Ranking 'S' > 'A' > 'B' > 'C' > 'D' > 'Unranked'                                                                                                                                                                                     |
| [BaseTournamentWinnerId](documentation/models/BaseTournamentWinnerId.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [BaseTournamentWinnerType](documentation/models/BaseTournamentWinnerType.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [VideogameId](documentation/models/VideogameId.md)                                                                 | A videogame ID                                                                                                                                                                                                                                                                                   |
| [TournamentRosterItem](documentation/models/TournamentRosterItem.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [BaseMatch](documentation/models/BaseMatch.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [BaseTeam](documentation/models/BaseTeam.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [TournamentTier_1](documentation/models/TournamentTier1.md)                                                        | The tier of the tournament, ranging from 'S' to 'Unranked'. Ranking 'S' > 'A' > 'B' > 'C' > 'D' > 'Unranked'                                                                                                                                                                                     |
| [TournamentVideogameTitle](documentation/models/TournamentVideogameTitle.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [TournamentWinnerId](documentation/models/TournamentWinnerId.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [TournamentWinnerType](documentation/models/TournamentWinnerType.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [BasePlayer](documentation/models/BasePlayer.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [MatchLive](documentation/models/MatchLive.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [MatchType](documentation/models/MatchType.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [MatchStatus](documentation/models/MatchStatus.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [Stream](documentation/models/Stream.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [BaseMatchWinnerId](documentation/models/BaseMatchWinnerId.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [MatchWinnerType](documentation/models/MatchWinnerType.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [StreamLanguage](documentation/models/StreamLanguage.md)                                                           | Language alpha-2 code according to ISO 649-1 standard.                                                                                                                                                                                                                                           |
| [Game](documentation/models/Game.md)                                                                               |                                                                                                                                                                                                                                                                                                  |
| [ValorantMapPick](documentation/models/ValorantMapPick.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [Opponent](documentation/models/Opponent.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [MatchResult](documentation/models/MatchResult.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [MatchVideogameTitle](documentation/models/MatchVideogameTitle.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [MatchVideogameVersion](documentation/models/MatchVideogameVersion.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [MatchWinnerId](documentation/models/MatchWinnerId.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [GameId](documentation/models/GameId.md)                                                                           | ID of the game. <br/>IDs are video game-specific, ie. a Valorant game and an Overwatch game can have the same game ID.                                                                                                                                                                           |
| [GameStatus](documentation/models/GameStatus.md)                                                                   | The game status                                                                                                                                                                                                                                                                                  |
| [GameWinner](documentation/models/GameWinner.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [GameWinnerType_1](documentation/models/GameWinnerType1.md)                                                        |                                                                                                                                                                                                                                                                                                  |
| [Id](documentation/models/Id.md)                                                                                   |                                                                                                                                                                                                                                                                                                  |
| [GameWinnerType_2](documentation/models/GameWinnerType2.md)                                                        |                                                                                                                                                                                                                                                                                                  |
| [OpponentType](documentation/models/OpponentType.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [MatchTeamResult](documentation/models/MatchTeamResult.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [MatchPlayerResult](documentation/models/MatchPlayerResult.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_1](documentation/models/Winner1_1.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_1](documentation/models/Winner2_1.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [PlayerCurrentTeam](documentation/models/PlayerCurrentTeam.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [Page_2](documentation/models/Page2.md)                                                                            |                                                                                                                                                                                                                                                                                                  |
| [VideogameSlug](documentation/models/VideogameSlug.md)                                                             | A videogame slug                                                                                                                                                                                                                                                                                 |
| [DeletionIncidentChangeType](documentation/models/DeletionIncidentChangeType.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [DeletionObject](documentation/models/DeletionObject.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [IncidentDeletionReasonDeleted](documentation/models/IncidentDeletionReasonDeleted.md)                             | The entity no longer exists.                                                                                                                                                                                                                                                                     |
| [OpponentId](documentation/models/OpponentId.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [ShortTournamentTier](documentation/models/ShortTournamentTier.md)                                                 | The tier of the tournament, ranging from 'S' to 'Unranked'. Ranking 'S' > 'A' > 'B' > 'C' > 'D' > 'Unranked'                                                                                                                                                                                     |
| [ShortTournamentVideogameTitle](documentation/models/ShortTournamentVideogameTitle.md)                             |                                                                                                                                                                                                                                                                                                  |
| [ShortTournamentWinnerId](documentation/models/ShortTournamentWinnerId.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [ShortTournamentWinnerType](documentation/models/ShortTournamentWinnerType.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [SearchOverValorantShortTournamentsTier_2](documentation/models/SearchOverValorantShortTournamentsTier2.md)        | The tier of the tournament, ranging from 'S' to 'Unranked'. Ranking 'S' > 'A' > 'B' > 'C' > 'D' > 'Unranked'                                                                                                                                                                                     |
| [CsgoGameMap](documentation/models/CsgoGameMap.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [FullGameMatch](documentation/models/FullGameMatch.md)                                                             | A match                                                                                                                                                                                                                                                                                          |
| [CsgoGamePlayer](documentation/models/CsgoGamePlayer.md)                                                           | Player's data for a game                                                                                                                                                                                                                                                                         |
| [CsgoRound](documentation/models/CsgoRound.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundsScore](documentation/models/CsgoRoundsScore.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoGameWinnerType](documentation/models/CsgoGameWinnerType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [FullGameMatchVideogameVersion](documentation/models/FullGameMatchVideogameVersion.md)                             |                                                                                                                                                                                                                                                                                                  |
| [FullGameMatchWinnerId](documentation/models/FullGameMatchWinnerId.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_2](documentation/models/Winner1_2.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_2](documentation/models/Winner2_2.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [CsgoOutcome](documentation/models/CsgoOutcome.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [CsgoSide](documentation/models/CsgoSide.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundStartEvent](documentation/models/CsgoRoundStartEvent.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundEndEvent](documentation/models/CsgoRoundEndEvent.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoKillEvent](documentation/models/CsgoKillEvent.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundStartEventDetails](documentation/models/CsgoRoundStartEventDetails.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [CsgoEventType](documentation/models/CsgoEventType.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundEndEventDetails](documentation/models/CsgoRoundEndEventDetails.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundWinner](documentation/models/CsgoRoundWinner.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundSide](documentation/models/CsgoRoundSide.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoKillEventDetails](documentation/models/CsgoKillEventDetails.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [Killer](documentation/models/Killer.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [CsgoRoundPlayer](documentation/models/CsgoRoundPlayer.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRoundTeam](documentation/models/CsgoFullRoundTeam.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRoundMap](documentation/models/CsgoFullRoundMap.md)                                                       | The location selected during the picks and bans phase for the game.                                                                                                                                                                                                                              |
| [CsgoFullRoundWinner](documentation/models/CsgoFullRoundWinner.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRoundTeamPlayer](documentation/models/CsgoFullRoundTeamPlayer.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRoundPlayerEconomy](documentation/models/CsgoFullRoundPlayerEconomy.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [Armor](documentation/models/Armor.md)                                                                             |                                                                                                                                                                                                                                                                                                  |
| [PrimaryWeapon](documentation/models/PrimaryWeapon.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [SecondaryWeapon](documentation/models/SecondaryWeapon.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoFullRoundUtility](documentation/models/CsgoFullRoundUtility.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatchGame](documentation/models/CsgoMatchGame.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatchPlayer](documentation/models/CsgoMatchPlayer.md)                                                         | Player's data for a CSGO Match                                                                                                                                                                                                                                                                   |
| [CsgoMatchVideogameTitle](documentation/models/CsgoMatchVideogameTitle.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatchVideogameVersion](documentation/models/CsgoMatchVideogameVersion.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatchWinnerId](documentation/models/CsgoMatchWinnerId.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoMatchGamePlayer](documentation/models/CsgoMatchGamePlayer.md)                                                 | Player's data for a Game in a CSGO Match                                                                                                                                                                                                                                                         |
| [CsgoMatchGameWinnerType](documentation/models/CsgoMatchGameWinnerType.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_3](documentation/models/Winner1_3.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_3](documentation/models/Winner2_3.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [CsgoTeamForAllStatsPlayers](documentation/models/CsgoTeamForAllStatsPlayers.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerForAllStatsPlayers](documentation/models/CsgoPlayerForAllStatsPlayers.md)                               |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStatsForAllPlayersByMatch](documentation/models/CsgoPlayerStatsForAllPlayersByMatch.md)                 | Statistics for all players for a match                                                                                                                                                                                                                                                           |
| [CsgoStatsCountsForMatch](documentation/models/CsgoStatsCountsForMatch.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStatsGameAverages](documentation/models/CsgoPlayerStatsGameAverages.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsRoundAverages](documentation/models/CsgoStatsRoundAverages.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsForPlayerByMatchCurrentTeam](documentation/models/CsgoStatsForPlayerByMatchCurrentTeam.md)               |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStatsByMatch](documentation/models/CsgoPlayerStatsByMatch.md)                                           | Statistics for a match                                                                                                                                                                                                                                                                           |
| [BaseCsgoGame](documentation/models/BaseCsgoGame.md)                                                               | A game                                                                                                                                                                                                                                                                                           |
| [CsgoTeamStatsByMatch](documentation/models/CsgoTeamStatsByMatch.md)                                               | Statistics for a match                                                                                                                                                                                                                                                                           |
| [BaseCsgoGameMap](documentation/models/BaseCsgoGameMap.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [BaseCsgoGameWinnerType](documentation/models/BaseCsgoGameWinnerType.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [CsgoTeamMapStats](documentation/models/CsgoTeamMapStats.md)                                                       | Statistics for a map                                                                                                                                                                                                                                                                             |
| [CsgoTeamStatsGameAverages](documentation/models/CsgoTeamStatsGameAverages.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsForPlayerCurrentTeam](documentation/models/CsgoStatsForPlayerCurrentTeam.md)                             |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStats](documentation/models/CsgoPlayerStats.md)                                                         | Statistics for all matches                                                                                                                                                                                                                                                                       |
| [CsgoStatsCounts](documentation/models/CsgoStatsCounts.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [CsgoStatsForPlayerBySerieCurrentTeam](documentation/models/CsgoStatsForPlayerBySerieCurrentTeam.md)               |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStatsBySerie](documentation/models/CsgoPlayerStatsBySerie.md)                                           | Statistics for a serie                                                                                                                                                                                                                                                                           |
| [CsgoTeamStatsBySerie](documentation/models/CsgoTeamStatsBySerie.md)                                               | Statistics for a serie                                                                                                                                                                                                                                                                           |
| [CsgoTeamStats](documentation/models/CsgoTeamStats.md)                                                             | Statistics for all matches                                                                                                                                                                                                                                                                       |
| [CsgoStatsForPlayerByTournamentCurrentTeam](documentation/models/CsgoStatsForPlayerByTournamentCurrentTeam.md)     |                                                                                                                                                                                                                                                                                                  |
| [CsgoPlayerStatsByTournament](documentation/models/CsgoPlayerStatsByTournament.md)                                 | Statistics for a tournament                                                                                                                                                                                                                                                                      |
| [CsgoTeamStatsByTournament](documentation/models/CsgoTeamStatsByTournament.md)                                     | Statistics for a tournament                                                                                                                                                                                                                                                                      |
| [CsgoWeaponKind](documentation/models/CsgoWeaponKind.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2GameMatch](documentation/models/Dota2GameMatch.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2FullGamePlayer](documentation/models/Dota2FullGamePlayer.md)                                                 | Player's data for a game                                                                                                                                                                                                                                                                         |
| [Dota2GameTeam](documentation/models/Dota2GameTeam.md)                                                             | Team's data for a game                                                                                                                                                                                                                                                                           |
| [Dota2GameWinnerType](documentation/models/Dota2GameWinnerType.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [Dota2GameMatchWinnerId](documentation/models/Dota2GameMatchWinnerId.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_4](documentation/models/Winner1_4.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_4](documentation/models/Winner2_4.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Dota2PerHeroAbility](documentation/models/Dota2PerHeroAbility.md)                                                 | An ability used by a hero in a game                                                                                                                                                                                                                                                              |
| [Dota2FullGamePlayerFaction](documentation/models/Dota2FullGamePlayerFaction.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [Dota2FullGamePlayerHero](documentation/models/Dota2FullGamePlayerHero.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [Dota2FullGamePlayerTeam](documentation/models/Dota2FullGamePlayerTeam.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [Opponent_1_1](documentation/models/Opponent1_1.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Opponent_2_1](documentation/models/Opponent2_1.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [BarracksStatus](documentation/models/BarracksStatus.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2Faction](documentation/models/Dota2Faction.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [TowerStatus](documentation/models/TowerStatus.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [Dota2FrameTeam](documentation/models/Dota2FrameTeam.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2FramePlayer](documentation/models/Dota2FramePlayer.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [Dota2FrameHero](documentation/models/Dota2FrameHero.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [BaseDota2GameWinnerType](documentation/models/BaseDota2GameWinnerType.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [Dota2TeamForAllStatsPlayers](documentation/models/Dota2TeamForAllStatsPlayers.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [Dota2PlayerForAllStatsPlayers](documentation/models/Dota2PlayerForAllStatsPlayers.md)                             |                                                                                                                                                                                                                                                                                                  |
| [Dota2PlayerStatsForAllPlayersByMatch](documentation/models/Dota2PlayerStatsForAllPlayersByMatch.md)               | Statistics for all players for a match                                                                                                                                                                                                                                                           |
| [Dota2PlayerAverages](documentation/models/Dota2PlayerAverages.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [Dota2PlayerStatsTotals](documentation/models/Dota2PlayerStatsTotals.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2StatsForPlayerCurrentTeam](documentation/models/Dota2StatsForPlayerCurrentTeam.md)                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2FavoriteHero](documentation/models/Dota2FavoriteHero.md)                                                     | Player's favorite heroes                                                                                                                                                                                                                                                                         |
| [Dota2GamePlayer](documentation/models/Dota2GamePlayer.md)                                                         | Player's data for a game                                                                                                                                                                                                                                                                         |
| [Dota2PlayerBySerieStat](documentation/models/Dota2PlayerBySerieStat.md)                                           | Player's statistics for a serie                                                                                                                                                                                                                                                                  |
| [Dota2TotalPlayerStat](documentation/models/Dota2TotalPlayerStat.md)                                               | Total Player's statistics                                                                                                                                                                                                                                                                        |
| [Dota2UsedItem](documentation/models/Dota2UsedItem.md)                                                             | An item used by a hero                                                                                                                                                                                                                                                                           |
| [Dota2GamePlayerFaction](documentation/models/Dota2GamePlayerFaction.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [Dota2GamePlayerHero](documentation/models/Dota2GamePlayerHero.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [Opponent_1_2](documentation/models/Opponent1_2.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Opponent_2_2](documentation/models/Opponent2_2.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Dota2StatsForPlayerBySerieCurrentTeam](documentation/models/Dota2StatsForPlayerBySerieCurrentTeam.md)             |                                                                                                                                                                                                                                                                                                  |
| [Dota2BannedHero](documentation/models/Dota2BannedHero.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [Dota2PickedHero](documentation/models/Dota2PickedHero.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [Dota2TeamBySerieStat](documentation/models/Dota2TeamBySerieStat.md)                                               | Team's statistics for a serie                                                                                                                                                                                                                                                                    |
| [Dota2TeamAverages](documentation/models/Dota2TeamAverages.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [Dota2TeamStatsTotals](documentation/models/Dota2TeamStatsTotals.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [Dota2TeamRatios](documentation/models/Dota2TeamRatios.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [Dota2TotalTeamStat](documentation/models/Dota2TotalTeamStat.md)                                                   | Total Team's statistics                                                                                                                                                                                                                                                                          |
| [Dota2StatsForPlayerByTournamentCurrentTeam](documentation/models/Dota2StatsForPlayerByTournamentCurrentTeam.md)   |                                                                                                                                                                                                                                                                                                  |
| [Dota2PlayerByTournamentStat](documentation/models/Dota2PlayerByTournamentStat.md)                                 | Player's statistics for a tournament                                                                                                                                                                                                                                                             |
| [Dota2TeamByTournamentStat](documentation/models/Dota2TeamByTournamentStat.md)                                     | Team's statistics for a tournament                                                                                                                                                                                                                                                               |
| [LiveEndpoint](documentation/models/LiveEndpoint.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LiveType](documentation/models/LiveType.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLGamePlayer](documentation/models/LoLGamePlayer.md)                                                             | Player's data for a Game                                                                                                                                                                                                                                                                         |
| [LoLGameTeam](documentation/models/LoLGameTeam.md)                                                                 | Team's data for a Game                                                                                                                                                                                                                                                                           |
| [LoLGameWinnerType](documentation/models/LoLGameWinnerType.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLGamePlayerChampion](documentation/models/LoLGamePlayerChampion.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLFlags](documentation/models/LoLFlags.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [BaseLoLItem](documentation/models/BaseLoLItem.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLKillCounters](documentation/models/LoLKillCounters.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLKillsSeries](documentation/models/LoLKillsSeries.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLMagicDamage](documentation/models/LoLMagicDamage.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLPhysicalDamage](documentation/models/LoLPhysicalDamage.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLGamePlayerRole](documentation/models/LoLGamePlayerRole.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerRunesReforged](documentation/models/LoLPlayerRunesReforged.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLTotalDamage](documentation/models/LoLTotalDamage.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLTrueDamage](documentation/models/LoLTrueDamage.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLWards](documentation/models/LoLWards.md)                                                                       |                                                                                                                                                                                                                                                                                                  |
| [Opponent_1_3](documentation/models/Opponent1_3.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Opponent_2_3](documentation/models/Opponent2_3.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [PrimaryPath](documentation/models/PrimaryPath.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [SecondaryPath](documentation/models/SecondaryPath.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerRuneShards](documentation/models/LoLPlayerRuneShards.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLRuneReforgedType](documentation/models/LoLRuneReforgedType.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [Defense](documentation/models/Defense.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [Flex](documentation/models/Flex.md)                                                                               |                                                                                                                                                                                                                                                                                                  |
| [Offense](documentation/models/Offense.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamColor](documentation/models/LoLTeamColor.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventPayload](documentation/models/LoLEventPayload.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLEventType](documentation/models/LoLEventType.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventPlayer](documentation/models/LoLEventPlayer.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLEventPlayerObject](documentation/models/LoLEventPlayerObject.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventPlayerType](documentation/models/LoLEventPlayerType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventChampion](documentation/models/LoLEventChampion.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLEventDrake](documentation/models/LoLEventDrake.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLEventHerald](documentation/models/LoLEventHerald.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLEventMinion](documentation/models/LoLEventMinion.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNashor](documentation/models/LoLEventNashor.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLEventTower](documentation/models/LoLEventTower.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNeutralMinion](documentation/models/LoLEventNeutralMinion.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLEventVoidgrub](documentation/models/LoLEventVoidgrub.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLEventUnknown](documentation/models/LoLEventUnknown.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLEventDrakeObject](documentation/models/LoLEventDrakeObject.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventDrakeType](documentation/models/LoLEventDrakeType.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLDrakeName](documentation/models/LoLDrakeName.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLDrakeType](documentation/models/LoLDrakeType.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventHeraldObject](documentation/models/LoLEventHeraldObject.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventHeraldType](documentation/models/LoLEventHeraldType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventHeraldValue](documentation/models/LoLEventHeraldValue.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventMinionObject](documentation/models/LoLEventMinionObject.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventMinionType](documentation/models/LoLEventMinionType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventMinionValue](documentation/models/LoLEventMinionValue.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNashorObject](documentation/models/LoLEventNashorObject.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNashorType](documentation/models/LoLEventNashorType.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNashorValue](documentation/models/LoLEventNashorValue.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventTowerObject](documentation/models/LoLEventTowerObject.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventTowerType](documentation/models/LoLEventTowerType.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLEventTowerValue](documentation/models/LoLEventTowerValue.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNeutralMinionObject](documentation/models/LoLEventNeutralMinionObject.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNeutralMinionType](documentation/models/LoLEventNeutralMinionType.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLEventNeutralMinionValue](documentation/models/LoLEventNeutralMinionValue.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLEventVoidgrubObject](documentation/models/LoLEventVoidgrubObject.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLEventVoidgrubType](documentation/models/LoLEventVoidgrubType.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLEventVoidgrubValue](documentation/models/LoLEventVoidgrubValue.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLEventUnknownType](documentation/models/LoLEventUnknownType.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLEventInhibitor](documentation/models/LoLEventInhibitor.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLEventInhibitorObject](documentation/models/LoLEventInhibitorObject.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLEventInhibitorType](documentation/models/LoLEventInhibitorType.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLEventInhibitorValue](documentation/models/LoLEventInhibitorValue.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLFrameTeam](documentation/models/LoLFrameTeam.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayersRole](documentation/models/LoLPlayersRole.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayersRoleDetail](documentation/models/LoLPlayersRoleDetail.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [BaseLoLChampion](documentation/models/BaseLoLChampion.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [BaseLoLSpell](documentation/models/BaseLoLSpell.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamLastGameWinnerType](documentation/models/LoLTeamLastGameWinnerType.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchGame](documentation/models/LoLMatchGame.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchPlayer](documentation/models/LoLMatchPlayer.md)                                                           | Player's data for a LoL Match                                                                                                                                                                                                                                                                    |
| [LoLMatchVideogameTitle](documentation/models/LoLMatchVideogameTitle.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchVideogameVersion](documentation/models/LoLMatchVideogameVersion.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchWinnerId](documentation/models/LoLMatchWinnerId.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchGamePlayer](documentation/models/LoLMatchGamePlayer.md)                                                   | Player's data for a Game in a LoL Match                                                                                                                                                                                                                                                          |
| [LoLMatchGameWinnerType](documentation/models/LoLMatchGameWinnerType.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchGamePlayerRole](documentation/models/LoLMatchGamePlayerRole.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLMatchPlayerRole](documentation/models/LoLMatchPlayerRole.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_5](documentation/models/Winner1_5.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_5](documentation/models/Winner2_5.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamForAllStatsPlayers](documentation/models/LoLTeamForAllStatsPlayers.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerForAllStatsPlayers](documentation/models/LoLPlayerForAllStatsPlayers.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerStatsForAllPlayersByMatch](documentation/models/LoLPlayerStatsForAllPlayersByMatch.md)                   | Statistics for all players for a match                                                                                                                                                                                                                                                           |
| [LoLPlayerAverages](documentation/models/LoLPlayerAverages.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerStatsTotals](documentation/models/LoLPlayerStatsTotals.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLAverageKillCounters](documentation/models/LoLAverageKillCounters.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [LoLAverageMagicDamage](documentation/models/LoLAverageMagicDamage.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLAveragePhysicalDamage](documentation/models/LoLAveragePhysicalDamage.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [LoLAverageTotalDamage](documentation/models/LoLAverageTotalDamage.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLAverageTrueDamage](documentation/models/LoLAverageTrueDamage.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerTotalKillCounters](documentation/models/LoLPlayerTotalKillCounters.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLStatsForPlayerCurrentTeam](documentation/models/LoLStatsForPlayerCurrentTeam.md)                               |                                                                                                                                                                                                                                                                                                  |
| [LoLFavoriteChampion](documentation/models/LoLFavoriteChampion.md)                                                 | A player's most used champion                                                                                                                                                                                                                                                                    |
| [LoLGamePlayerForStats](documentation/models/LoLGamePlayerForStats.md)                                             | Player's data for a Game                                                                                                                                                                                                                                                                         |
| [LoLPlayerBySerieStat](documentation/models/LoLPlayerBySerieStat.md)                                               | Player's statistics for a serie                                                                                                                                                                                                                                                                  |
| [LoLTotalPlayerStat](documentation/models/LoLTotalPlayerStat.md)                                                   | Total Player's statistics                                                                                                                                                                                                                                                                        |
| [LoLUsedItem](documentation/models/LoLUsedItem.md)                                                                 | An item used by a champion                                                                                                                                                                                                                                                                       |
| [LoLGamePlayerForStatsChampion](documentation/models/LoLGamePlayerForStatsChampion.md)                             |                                                                                                                                                                                                                                                                                                  |
| [LoLGamePlayerDamageForStats](documentation/models/LoLGamePlayerDamageForStats.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [LoLGamePlayerForStatsRole](documentation/models/LoLGamePlayerForStatsRole.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [Opponent_1_4](documentation/models/Opponent1_4.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Opponent_2_4](documentation/models/Opponent2_4.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [LoLStatsForPlayerBySerieCurrentTeam](documentation/models/LoLStatsForPlayerBySerieCurrentTeam.md)                 |                                                                                                                                                                                                                                                                                                  |
| [LoLBannedChampion](documentation/models/LoLBannedChampion.md)                                                     | A team's banned champion                                                                                                                                                                                                                                                                         |
| [LoLPickedChampion](documentation/models/LoLPickedChampion.md)                                                     | A team's picked champion                                                                                                                                                                                                                                                                         |
| [LoLTeamBySerieStat](documentation/models/LoLTeamBySerieStat.md)                                                   | Team's statistics for a serie                                                                                                                                                                                                                                                                    |
| [LoLTeamAverages](documentation/models/LoLTeamAverages.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamStatsTotals](documentation/models/LoLTeamStatsTotals.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [LoLTeamRatios](documentation/models/LoLTeamRatios.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [LoLTotalTeamStat](documentation/models/LoLTotalTeamStat.md)                                                       | Total Team's statistics                                                                                                                                                                                                                                                                          |
| [LoLStatsForPlayerByTournamentCurrentTeam](documentation/models/LoLStatsForPlayerByTournamentCurrentTeam.md)       |                                                                                                                                                                                                                                                                                                  |
| [LoLPlayerByTournamentStat](documentation/models/LoLPlayerByTournamentStat.md)                                     | Player's statistics for a tournament                                                                                                                                                                                                                                                             |
| [LoLTeamByTournamentStat](documentation/models/LoLTeamByTournamentStat.md)                                         | Team's statistics for a tournament                                                                                                                                                                                                                                                               |
| [LoLRunePathRunesObject](documentation/models/LoLRunePathRunesObject.md)                                           |                                                                                                                                                                                                                                                                                                  |
| [MatchTeamOpponentsObject](documentation/models/MatchTeamOpponentsObject.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [MatchPlayerOpponentsObject](documentation/models/MatchPlayerOpponentsObject.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [OpponentTypeTeam](documentation/models/OpponentTypeTeam.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [OpponentTypePlayer](documentation/models/OpponentTypePlayer.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [MatchOpponentBasePlayer](documentation/models/MatchOpponentBasePlayer.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [OwGameMap](documentation/models/OwGameMap.md)                                                                     |                                                                                                                                                                                                                                                                                                  |
| [OwGameRound](documentation/models/OwGameRound.md)                                                                 |                                                                                                                                                                                                                                                                                                  |
| [OwGameWinnerType](documentation/models/OwGameWinnerType.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [OwMapGameMode](documentation/models/OwMapGameMode.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [OwGameRoundTeam](documentation/models/OwGameRoundTeam.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [OwGameRoundPlayer](documentation/models/OwGameRoundPlayer.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [OwGameRoundPlayerHero](documentation/models/OwGameRoundPlayerHero.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [OwHeroRole](documentation/models/OwHeroRole.md)                                                                   |                                                                                                                                                                                                                                                                                                  |
| [Opponent_1_5](documentation/models/Opponent1_5.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [Opponent_2_5](documentation/models/Opponent2_5.md)                                                                |                                                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerByGameCurrentTeam](documentation/models/OwStatsForPlayerByGameCurrentTeam.md)                     |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStatsByGame](documentation/models/OwPlayerStatsByGame.md)                                                 | Player's statistics for a game                                                                                                                                                                                                                                                                   |
| [OwPlayerAverages](documentation/models/OwPlayerAverages.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [OwGameStatsGame](documentation/models/OwGameStatsGame.md)                                                         | A game                                                                                                                                                                                                                                                                                           |
| [OwPlayer10MinAverages](documentation/models/OwPlayer10MinAverages.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerGameAverages](documentation/models/OwPlayerGameAverages.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerGameTotalsForGame](documentation/models/OwPlayerGameTotalsForGame.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [OwGameStatsGameMap](documentation/models/OwGameStatsGameMap.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [GamelessFullGameMatch](documentation/models/GamelessFullGameMatch.md)                                             | A match                                                                                                                                                                                                                                                                                          |
| [OwGameStatsGameWinnerType](documentation/models/OwGameStatsGameWinnerType.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [GamelessFullGameMatchVideogameVersion](documentation/models/GamelessFullGameMatchVideogameVersion.md)             |                                                                                                                                                                                                                                                                                                  |
| [GamelessFullGameMatchWinnerId](documentation/models/GamelessFullGameMatchWinnerId.md)                             |                                                                                                                                                                                                                                                                                                  |
| [Winner_1_6](documentation/models/Winner1_6.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [Winner_2_6](documentation/models/Winner2_6.md)                                                                    |                                                                                                                                                                                                                                                                                                  |
| [OwTeamForAllStatsPlayers](documentation/models/OwTeamForAllStatsPlayers.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerForAllStatsPlayers](documentation/models/OwPlayerForAllStatsPlayers.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStatsForAllPlayersByMatch](documentation/models/OwPlayerStatsForAllPlayersByMatch.md)                     | Statistics for all players for a match                                                                                                                                                                                                                                                           |
| [OwPlayerTotals](documentation/models/OwPlayerTotals.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerByMatchCurrentTeam](documentation/models/OwStatsForPlayerByMatchCurrentTeam.md)                   |                                                                                                                                                                                                                                                                                                  |
| [OwFavoriteHero](documentation/models/OwFavoriteHero.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStatsByMatch](documentation/models/OwPlayerStatsByMatch.md)                                               | Player's statistics for a match                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerCurrentTeam](documentation/models/OwStatsForPlayerCurrentTeam.md)                                 |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStats](documentation/models/OwPlayerStats.md)                                                             | Player's statistics                                                                                                                                                                                                                                                                              |
| [OwStatsForPlayerBySerieCurrentTeam](documentation/models/OwStatsForPlayerBySerieCurrentTeam.md)                   |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStatsBySerie](documentation/models/OwPlayerStatsBySerie.md)                                               | Player's statistics for a serie                                                                                                                                                                                                                                                                  |
| [OwStatsForPlayerByTournamentCurrentTeam](documentation/models/OwStatsForPlayerByTournamentCurrentTeam.md)         |                                                                                                                                                                                                                                                                                                  |
| [OwPlayerStatsByTournament](documentation/models/OwPlayerStatsByTournament.md)                                     | Player's statistics for a tournament                                                                                                                                                                                                                                                             |
| [PreviousMatch](documentation/models/PreviousMatch.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [BracketWinnerId](documentation/models/BracketWinnerId.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [PreviousMatchType](documentation/models/PreviousMatchType.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [TeamRosters](documentation/models/TeamRosters.md)                                                                 | Rosters for a a series or a tournament with team participants                                                                                                                                                                                                                                    |
| [PlayerRosters](documentation/models/PlayerRosters.md)                                                             | Rosters for a series or a tournament with player participants                                                                                                                                                                                                                                    |
| [BracketStanding](documentation/models/BracketStanding.md)                                                         |                                                                                                                                                                                                                                                                                                  |
| [GroupStanding](documentation/models/GroupStanding.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [AbilityType](documentation/models/AbilityType.md)                                                                 | Ability type                                                                                                                                                                                                                                                                                     |
| [ValorantAbilityType](documentation/models/ValorantAbilityType.md)                                                 | Ability type                                                                                                                                                                                                                                                                                     |
| [ValorantGameMap](documentation/models/ValorantGameMap.md)                                                         | An object that represents a Valorant map                                                                                                                                                                                                                                                         |
| [ValorantGameRound](documentation/models/ValorantGameRound.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantGameTeam](documentation/models/ValorantGameTeam.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [ValorantGameRoundAttacker](documentation/models/ValorantGameRoundAttacker.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantGameRoundDefender](documentation/models/ValorantGameRoundDefender.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantGameRoundOutcome](documentation/models/ValorantGameRoundOutcome.md)                                       | How was the round finished. <br/>`spike_exploded`: spike exploded <br/>`defenders_eliminated`: attackers killed all defenders <br/>`spike_defused`: spike defused <br/>`attack_timeout`: attackers failed to plant the spike in time <br/>`attackers_eliminated`: defenders killed all attackers |
| [ValorantGameRoundWinner](documentation/models/ValorantGameRoundWinner.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [ValorantTeamSide](documentation/models/ValorantTeamSide.md)                                                       | Team side in the round                                                                                                                                                                                                                                                                           |
| [ValorantGamePlayer](documentation/models/ValorantGamePlayer.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantShortAgent](documentation/models/ValorantShortAgent.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantPlayerClutchWins](documentation/models/ValorantPlayerClutchWins.md)                                       | Round wins when the player was the last team member alive                                                                                                                                                                                                                                        |
| [ValorantPlayerStreaks](documentation/models/ValorantPlayerStreaks.md)                                             | Streaks done by the player (in a given round)                                                                                                                                                                                                                                                    |
| [ValorantKillEvent](documentation/models/ValorantKillEvent.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantSpikePlantedEvent](documentation/models/ValorantSpikePlantedEvent.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantSpikeDefusedEvent](documentation/models/ValorantSpikeDefusedEvent.md)                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantKillEventDetails](documentation/models/ValorantKillEventDetails.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [ValorantEventType](documentation/models/ValorantEventType.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [ValorantEventKiller](documentation/models/ValorantEventKiller.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [ValorantEventVictim](documentation/models/ValorantEventVictim.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [Ability](documentation/models/Ability.md)                                                                         |                                                                                                                                                                                                                                                                                                  |
| [BaseValorantAgent](documentation/models/BaseValorantAgent.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [Weapon](documentation/models/Weapon.md)                                                                           |                                                                                                                                                                                                                                                                                                  |
| [ValorantSpikeEventPlayer](documentation/models/ValorantSpikeEventPlayer.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [ValorantEventPlayer](documentation/models/ValorantEventPlayer.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [ValorantFullRoundAttackerTeam](documentation/models/ValorantFullRoundAttackerTeam.md)                             |                                                                                                                                                                                                                                                                                                  |
| [ValorantFullRoundDefenderTeam](documentation/models/ValorantFullRoundDefenderTeam.md)                             |                                                                                                                                                                                                                                                                                                  |
| [ValorantFullRoundPlayer](documentation/models/ValorantFullRoundPlayer.md)                                         |                                                                                                                                                                                                                                                                                                  |
| [ValorantPlayerShield](documentation/models/ValorantPlayerShield.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [BaseValorantWeapon](documentation/models/BaseValorantWeapon.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantPlayerMatchStats](documentation/models/ValorantPlayerMatchStats.md)                                       |                                                                                                                                                                                                                                                                                                  |
| [ValorantAgentStats](documentation/models/ValorantAgentStats.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [ValorantTeamClutchWins](documentation/models/ValorantTeamClutchWins.md)                                           | Rounds wins with a single team member alive                                                                                                                                                                                                                                                      |
| [BaseValorantGame](documentation/models/BaseValorantGame.md)                                                       | A game                                                                                                                                                                                                                                                                                           |
| [ValorantTeamMapStats](documentation/models/ValorantTeamMapStats.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [ValorantTeamStreaks](documentation/models/ValorantTeamStreaks.md)                                                 | Streaks done by a team member (in a given round)                                                                                                                                                                                                                                                 |
| [BaseValorantTeam](documentation/models/BaseValorantTeam.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [BaseValorantGameMap](documentation/models/BaseValorantGameMap.md)                                                 | An object that represents a Valorant map                                                                                                                                                                                                                                                         |
| [VideogameLoL](documentation/models/VideogameLoL.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [VideogameCsgo](documentation/models/VideogameCsgo.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [VideogameDota2](documentation/models/VideogameDota2.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [VideogameOverwatch](documentation/models/VideogameOverwatch.md)                                                   |                                                                                                                                                                                                                                                                                                  |
| [VideogamePubg](documentation/models/VideogamePubg.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [VideogameRocketLeague](documentation/models/VideogameRocketLeague.md)                                             |                                                                                                                                                                                                                                                                                                  |
| [VideogameCodmw](documentation/models/VideogameCodmw.md)                                                           |                                                                                                                                                                                                                                                                                                  |
| [VideogameR6siege](documentation/models/VideogameR6siege.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [VideogameFifa](documentation/models/VideogameFifa.md)                                                             |                                                                                                                                                                                                                                                                                                  |
| [VideogameValorant](documentation/models/VideogameValorant.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [VideogameKog](documentation/models/VideogameKog.md)                                                               |                                                                                                                                                                                                                                                                                                  |
| [VideogameLolWildRift](documentation/models/VideogameLolWildRift.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [VideogameStarcraft2](documentation/models/VideogameStarcraft2.md)                                                 |                                                                                                                                                                                                                                                                                                  |
| [VideogameStarcraftBroodWar](documentation/models/VideogameStarcraftBroodWar.md)                                   |                                                                                                                                                                                                                                                                                                  |
| [VideogameESoccer](documentation/models/VideogameESoccer.md)                                                       |                                                                                                                                                                                                                                                                                                  |
| [VideogameEBasketball](documentation/models/VideogameEBasketball.md)                                               |                                                                                                                                                                                                                                                                                                  |
| [VideogameECricket](documentation/models/VideogameECricket.md)                                                     |                                                                                                                                                                                                                                                                                                  |
| [VideogameLeague](documentation/models/VideogameLeague.md)                                                         |                                                                                                                                                                                                                                                                                                  |

</details>

## License

This SDK is licensed under the MIT License.

See the [LICENSE](LICENSE) file for more details.

<!-- This file was generated by liblab | https://liblab.com/ -->
